@@ -873,10 +873,11 @@ compatibility with the original codemod.",
     let hidden = matches.is_present("hidden");
     let print_changed_files = matches.is_present("print_changed_files");
     let regex_str = matches.value_of("match").expect("match is required!");
-    let maybe_escaped_regex = if matches.is_present("fixed_strings") {
-        regex::escape(regex_str)
+    let subst = matches.value_of("subst").expect("subst is required!");
+    let (maybe_escaped_regex, subst) = if matches.is_present("fixed_strings") {
+        (regex::escape(regex_str), subst.replace("$", "$$"))
     } else {
-        regex_str.to_string()
+        (regex_str.to_string(), subst.to_string())
     };
     let regex = RegexBuilder::new(&maybe_escaped_regex)
         .case_insensitive(ignore_case)
@@ -896,13 +897,12 @@ not what you want. Press Enter to continue anyway or Ctrl-C to quit.",
         .multi_line(true)
         .dot_matches_new_line(multiline)
         .build(&maybe_escaped_regex)?;
-    let subst = matches.value_of("subst").expect("subst is required!");
 
     if accept_all {
         Fastmod::run_fast(
             &regex,
             &matcher,
-            subst,
+            &subst,
             dirs,
             file_set,
             hidden,
@@ -910,7 +910,7 @@ not what you want. Press Enter to continue anyway or Ctrl-C to quit.",
         )
     } else {
         Fastmod::new(accept_all, hidden, print_changed_files)
-            .run_interactive(&regex, &matcher, subst, dirs, file_set)
+            .run_interactive(&regex, &matcher, &subst, dirs, file_set)
     }
 }
 
@@ -926,7 +926,7 @@ mod tests {
     use std::io::Write;
 
     use assert_cmd::Command;
-    use tempdir::TempDir;
+    use tempfile::TempDir;
 
     use super::*;
 
@@ -942,7 +942,7 @@ mod tests {
     fn create_test_files<'a>(
         names_and_contents: impl IntoIterator<Item = &'a (&'a str, &'a str)>,
     ) -> TempDir {
-        let dir = TempDir::new("fastmodtest").unwrap();
+        let dir = TempDir::with_prefix("fastmodtest.").unwrap();
         for (name, contents) in names_and_contents {
             let path = dir.path().join(name);
             let mut file = File::create(path.clone()).unwrap();
@@ -1048,7 +1048,7 @@ mod tests {
 
     #[test]
     fn test_print_changed_files() {
-        let dir = TempDir::new("fastmodtest").unwrap();
+        let dir = TempDir::with_prefix("fastmodtest.").unwrap();
         let mut expected_changed_files = Vec::new();
         for file_num in 1..6 {
             let path = dir.path().join(format!("file{}.c", file_num));
@@ -1173,4 +1173,25 @@ mod tests {
             .assert()
             .success();
     }
+
+    #[test]
+    fn test_dollar_sign_in_replacement_string_with_fixed_strings() {
+        let contents = "something";
+        let dir = create_test_files(&[("foo.txt", contents)]);
+        Command::cargo_bin("fastmod")
+            .unwrap()
+            .args(&[
+                "-F",
+                "something",
+                "$foo.bar",
+                "--dir",
+                dir.path().to_str().unwrap(),
+            ])
+            .write_stdin("y\n")
+            .assert()
+            .success();
+        let file_path = dir.path().join("foo.txt");
+        let new_contents = read_to_string(file_path).unwrap();
+        assert_eq!(new_contents, "$foo.bar");
+    }
 }
